==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebSortingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebGroupingExpressionDescriptionMetadata } from "./WebGroupingExpressionDescriptionMetadata";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebSortingEventArgsDetailDescription } from "./WebSortingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebSortingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingEventArgsDetailDescriptionMetadata.a == null) {
                WebSortingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingEventArgsDetailDescriptionMetadata.c(WebSortingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebSortingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebSortingEventArgsDetailDescriptionMetadata.a);
            WebSortingExpressionDescriptionMetadata.d(a);
            WebGroupingExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:SortingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("SortingExpressions", "Array:WebSortingExpressionDescription:SortingExpression");
            a.item("GroupingExpressions", "Array:WebGroupingExpressionDescription:GroupingExpression");
        }
        static d(a) {
            WebSortingEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebSortingEventArgsDetail", () => new WebSortingEventArgsDetailDescription());
            a.ac("WebSortingEventArgsDetail", WebSortingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebSortingEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingEventArgsDetailDescriptionMetadata, 'WebSortingEventArgsDetailDescriptionMetadata');
    WebSortingEventArgsDetailDescriptionMetadata.a = null;
    return WebSortingEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebSortingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebGroupingExpressionDescriptionMetadata } from "./WebGroupingExpressionDescriptionMetadata";
import { WebSortingEventArgsDetailDescription } from "./WebSortingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebSortingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSortingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebSortingEventArgsDetailDescriptionMetadata.a == null) {
                WebSortingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSortingEventArgsDetailDescriptionMetadata.c(WebSortingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebSortingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebSortingEventArgsDetailDescriptionMetadata.a);
            WebSortingExpressionDescriptionMetadata.d(a);
            WebGroupingExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SortingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("SortingExpressions", "Array:WebSortingExpressionDescription:SortingExpression");
            a.item("GroupingExpressions", "Array:WebGroupingExpressionDescription:GroupingExpression");
            a.item("Owner", "Unknown");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebSortingEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebSortingEventArgsDetail", () => new WebSortingEventArgsDetailDescription());
            a.ad("WebSortingEventArgsDetail", WebSortingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebSortingEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSortingEventArgsDetailDescriptionMetadata, 'WebSortingEventArgsDetailDescriptionMetadata');
    WebSortingEventArgsDetailDescriptionMetadata.a = null;
    return WebSortingEventArgsDetailDescriptionMetadata;
})();
